@@ -42,6 +42,11 @@
 //class KMagSelRect;
 #include "kmagselrect.h"
 
+#include "focustrackconfig.h"
+#ifdef QAccessibilityClient_FOUND
+#include <qaccessibilityclient/registry.h>
+#endif
+
 /**
  * The KMagZoomView class provides the view widget for the KmagApp instance.
  *
@@ -68,9 +73,11 @@ class KMagZoomView : public QAbstractScrollArea
 
     /// Returns the status of followMouse
     bool getFollowMouse() const { return m_followMouse; }
-    
+
+#ifdef QAccessibilityClient_FOUND
     /// Returns the status of followFocus
     bool getFollowFocus() const { return m_followFocus; }
+#endif
 
     /// Get the status of "show rect. always"
     bool getShowSelRect() const { return (m_selRect.getAlwaysVisible()); }
@@ -106,9 +113,14 @@ class KMagZoomView : public QAbstractScrollArea
 
     /// Set grab-window-follows-mouse mode
     void followMouse(bool follow = true);
+
+#ifdef QAccessibilityClient_FOUND
+    /// Set grab-window-follows-mouse-and-keyboard-focus mode
+    void followBoth(bool follow = true);
     
     /// Set grab-window-follows-keyboard-focus mode
     void followFocus(bool follow = true);
+#endif
 
     /// Shows/Hides the selection marker
     void showSelRect(bool show=true);
@@ -128,10 +140,11 @@ class KMagZoomView : public QAbstractScrollArea
     /// Fits the zoom view to the zoom view window
     void fitToWindow();
 
+#ifdef QAccessibilityClient_FOUND
   private slots:
     /// Called from a dbus service when followFocus is true
-    void focusChanged(int px, int py, int rx, int ry, int rwidth, int rheight);
-    
+    void focusChanged(const QAccessibleClient::AccessibleObject &object);
+#endif
   protected:
     /// Called when the widget is hidden
     void hideEvent( QHideEvent * e);
@@ -185,6 +198,12 @@ class KMagZoomView : public QAbstractScrollArea
     void setupMatrix();
 
   private:
+
+#ifdef QAccessibilityClient_FOUND
+    /// Global Accessibility Registry
+    QAccessibleClient::Registry m_registry;
+#endif
+
     /// Stores the pixmap which is recolored from the grabbed one
     QPixmap m_coloredPixmap;
 
@@ -206,8 +225,10 @@ class KMagZoomView : public QAbstractScrollArea
     /// Saves the center of the grab window
     QPoint m_oldCenter;
     
+#ifdef QAccessibilityClient_FOUND
     /// Saves the keyboard focus position
     QPoint m_oldFocus;
+#endif
 
     /// Possible modes for the mouse to be in
     enum KMagMouseMode {
@@ -240,6 +261,7 @@ class KMagZoomView : public QAbstractScrollArea
 
     /// To follow keyboard focus or not
     bool m_followFocus;
+    bool m_followBoth;
 
     /// State of refreshing - on or off
     bool m_refreshSwitch;
